"""credits.py - a context for displaying a game's credits

This file is part of Gummworld2.

Gummworld2 is free software: you can redistribute it and/or modify it
under the terms of the GNU Lesser General Public License as published
by the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Gummworld2 is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with Gummworld2.  If not, see <http://www.gnu.org/licenses/>.
"""

import pygame
from pygame.locals import *

import gummworld2
from gummworld2 import data, State

import settings


TEXT = """
Thanks for playing!

This game was made possible by GOD.
Make no mistake, all things were made by him. (John 1:3)
If you liked this game, then get a load of this...

And it shall come to pass, that whosoever shall call on
the name of the Lord shall be saved. (Act 2:21)

All that the Father giveth me shall come to me;
and him that cometh to me I will in no wise cast out.
(John 6:37)

And [the condemned thief] said unto Jesus, Lord, remember
me when thou comest into thy kingdom. And Jesus said unto
him, Verily I say unto thee, To day shalt thou be with me
in paradise. (Luk 23:42-43)

By grace are ye saved through faith;
and that not of yourselves: it is the gift of God.
Not of works, lest any man should boast. (Eph 2:8-9)

Sirs, what must I do to be saved? 
And they said, Believe on the Lord Jesus Christ,
and thou shalt be saved, and thy house. (Act 16:30-31)

Ask, and it shall be given you; seek, and ye shall find;
knock, and it shall be opened unto you. For every one that
asketh receiveth; and he that seeketh findeth; and to him
that knocketh it shall be opened. (Luk 11:9)

It is there for the asking. Man, oh man, how cool is that!
And you know what? Where we're headed in the next few months
to years, this is critical knowledge. Secure you place,
while he can be found. Read the book of John TODAY and find
what you seek.

Keywords: Supernatural. Powers. Alien tech. Hybrids. Giants.
Dark mysteries. Diabolical conspiracies. Forbidden magic.
Dimensional gates. Ancient chess match. Miracles. Divine
intervention, retribution, and salvation.

God bless you.
""".split('\n')

while TEXT[0] == '':
    del TEXT[0]
while TEXT[-1] == '':
    del TEXT[-1]


class Credits(gummworld2.Engine):
    
    def __init__(self):
        gummworld2.Engine.__init__(self,
            resolution=settings.resolution,
            update_speed=60, frame_speed=60,
        )
        name = data.filepath('font', 'Vera.ttf')
        self.font = pygame.font.Font(name, 20)
        self.images = []
        color = Color('orange')
        self.max_y = 0
        for text in TEXT:
            im = self.font.render(text, 1, color)
            self.images.append(im)
            self.max_y += im.get_height()
        print self.max_y
        self.y = 0
        self.scroll = 0
    
    def update(self, dt):
        if self.scroll:
            self.y += self.scroll * dt * self.font.get_height() * 2
            screen_height = State.screen.rect.h
            if self.y > 0:
                self.y = 0
            elif self.y < -(self.max_y - screen_height):
                self.y = -(self.max_y - screen_height)
    
    def draw(self, dt):
        self.screen.fill((0,0,0))
        self.draw_text()
        self.screen.flip()
    
    def draw_text(self):
        surf = State.screen.surface
        screen_rect = State.screen.rect
        y = self.y
        for im in self.images:
            h = im.get_height()
            bottom = y + h
            if bottom >= 0 and bottom <= screen_rect.h:
                r = im.get_rect(centerx=screen_rect.centerx, y=round(y))
                surf.blit(im, r)
            y += h
    
    def on_key_down(self, unicode, key, mod):
        if key == K_ESCAPE:
            self.on_quit()
        elif key == K_DOWN:
            self.scroll = -1
        elif key == K_UP:
            self.scroll = 1
    
    def on_key_up(self, key, mod):
        if key == K_DOWN:
            self.scroll = 0
        elif key == K_UP:
            self.scroll = 0
    
    def on_quit(self):
        self.pop()
