"""gummworld2.py - startup and runtime settings file

This file is part of Gummworld2.

Gummworld2 is free software: you can redistribute it and/or modify it
under the terms of the GNU Lesser General Public License as published
by the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Gummworld2 is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with Gummworld2.  If not, see <http://www.gnu.org/licenses/>.

Usage
=====
Settings in this file should always be accessed like so:
    
    import settings
    if settings.whatever: ...
    settings.whatever = value

This insures that runtime changes will be noticed by other modules that import
the settings module. Of course, one can always make local copies of the values
if static behavior is desired.
"""

import pygame

import gummworld2


## Display
caption = 'Harvest Moon'
resolution = 1024,768       # screen size in pixels: width,height
resolution = 800,600        # screen size in pixels: width,height
fullscreen = False          # open fullscreen if True
update_speed = 90           # physics ticks/sec; clock uses fixed time step
frame_speed = 0             # frame throttle frames/sec; 0=unlimited
dt = 1.0/update_speed

## Game
ground_level = resolution[1] * 7/10
player_speed = 3.0              # how fast player walks
G = 9.8                         # gravity
cheese_cooldown = 1.0 / 15.0    # cheese fire rate per second
cheese_speed = 1000.0           # cheese px per second
tether_cooldown = 2.0           # tether fire rate per second
tether_speed = 600.0            # tether px per second
moon_freq = [3]*7 + [2]*5 + [1]*3 + [0]*2   # input to random.choice()
moon_speed = 20                 # px per second
moon_y = 50, resolution[1]/2    # Y placement range
moon_size = 10,30               # radius range

## Graphics
# Defaults already set for graphics asset paths. You can add new subdirs like so.
#gummworld2.data.set_subdir('myname', 'subdir')

## Sound
# Defaults already set for sound asset paths. You can add new subdirs like so.
gummworld2.data.set_subdir('music', 'music')
play_music = False              # on/off
intermission = 35.0             # seconds between songs
intermission = 5.0             # seconds between songs
music_volume = 0.7              # 0.0 - 1.0

## UI
show_hud = True
fgcolor = pygame.Color(135, 206, 250)
bgcolor = pygame.Color(52, 69, 52)
bgcolor = pygame.Color(31, 41, 31)
KEYS = dict(
    left  = (pygame.K_LEFT,pygame.K_a),
    right = (pygame.K_RIGHT,pygame.K_d),
    jump  = (pygame.K_SPACE,pygame.K_UP,pygame.K_w),
    swaptool = (pygame.K_TAB,),
)

## Debug
profile = False                             # run cProfile if True
bypass_menu = (None, 'game', 'credits')[0]  # bypass mainmenu
test_awards = False

## Custom
import os
os.environ['SDL_VIDEO_CENTERED'] = '1'

# Gummbum's development preferences... remove or add a case for your own.
who = ''
try:
    if who == 'Gumm':
        print '## CUSTOM SETTINGS FOR Gumm (see settings.py)'
        bypass_menu = (None, 'game', 'credits')[1]
        play_music = False
        test_awards = True
        show_hud = True
except:
    pass

del os,who
